# Testing blank 50 slide for quick access of particular slide.
from pippt import *

app = Pippt()

frame_0=add_slide()
frame_1=add_slide()
frame_2=add_slide()
frame_3=add_slide()
frame_4=add_slide()
frame_5=add_slide()
frame_6=add_slide()
frame_7=add_slide()
frame_8=add_slide()
frame_9=add_slide()

frame_10=add_slide()
frame_11=add_slide()
frame_12=add_slide()
frame_13=add_slide()
frame_14=add_slide()
frame_15=add_slide()
frame_16=add_slide()
frame_17=add_slide()
frame_18=add_slide()
frame_19=add_slide()

frame_20=add_slide()
frame_21=add_slide()
frame_22=add_slide()
frame_23=add_slide()
frame_24=add_slide()
frame_25=add_slide()
frame_26=add_slide()
frame_27=add_slide()
frame_28=add_slide()
frame_29=add_slide()

frame_30=add_slide()
frame_31=add_slide()
frame_32=add_slide()
frame_33=add_slide()
frame_34=add_slide()
frame_35=add_slide()
frame_36=add_slide()
frame_37=add_slide()
frame_38=add_slide()
frame_39=add_slide()

frame_40=add_slide()
frame_41=add_slide()
frame_42=add_slide()
frame_43=add_slide()
frame_44=add_slide()
frame_45=add_slide()
frame_46=add_slide()
frame_47=add_slide()
frame_48=add_slide()
frame_49=add_slide()


app.bundle(frame_0, frame_1, frame_2, frame_3, frame_4,
           frame_5, frame_6, frame_7, frame_8, frame_9,
           frame_10, frame_11, frame_12, frame_13, frame_14,
           frame_15, frame_16, frame_17, frame_18, frame_19,
           frame_20, frame_21, frame_22, frame_23, frame_24,
           frame_25, frame_26, frame_27, frame_28, frame_29,
           frame_30, frame_31, frame_32, frame_33, frame_34,
           frame_35, frame_36, frame_37, frame_38, frame_39,
           frame_40, frame_41, frame_42, frame_43, frame_44,
           frame_45, frame_46, frame_47, frame_48, frame_49)

app.mainloop()
